#
# Please do not update/rebuild/touch this package before asking first
# to mikala and/or neoclust and/or daviddavid
# This package is part of the KDE Stack.
#

%ifarch %{ix86} x86_64
%define build_docs 1
%else
%define build_docs 0
%endif

%define oname kdb
%define rel 10
%define commit 48f9167e37c9a2d024c525cab0ba65a2e02e248f
%define date 20220620

Name:           kdb
Version:        3.2.90
Release:        %mkrel %rel.git%{date}
Summary:        A database connectivity and creation framework for various database vendors
Group:          Graphical desktop/KDE
License:        GPLv2+
URL:            https://community.kde.org/KDb
#modified tarball with po directory from 3.2.0
Source0:        https://download.kde.org/stable/%{oname}/src/%{oname}-%{commit}.tar.xz

## upstream patches
# Patch1:         0001-PgSQL-driver_fix-build-with-PostgreSQL-12+.patch
## upstreamable patches
# fix/santitize KDb3.pc dependencies
Patch100:       kdb-3.2.0-pkgconfig.patch

BuildRequires:  kf5-macros

BuildRequires:  mysql-devel
BuildRequires:  pkgconfig(libpq) >= 9.6
BuildRequires:  pkgconfig(sqlite3) >= 3.19.3

BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)

BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5I18n)

BuildRequires:  icu-devel

%description
A database connectivity and creation framework for various database vendors.

%files -f %{name}_qt.lang
%_kf5_bindir/kdb3_sqlite3_dump
%_qt5_plugindir/kdb3/kdb_sqlitedriver.so
%_qt5_plugindir/kdb3/kdb_mysqldriver.so
%_qt5_plugindir/kdb3/kdb_postgresqldriver.so
%_qt5_plugindir/kdb3/sqlite3/kdb_sqlite_icu.so

#--------------------------------------------------------------------

%define kdb_major 4
%define libkdb %mklibname kdb3_ %{kdb_major}

%package -n %libkdb
Summary:        A database connectivity and creation framework for various database vendors
Group:          System/Libraries

%description -n %libkdb
A database connectivity and creation framework for various database vendors.

%files -n %libkdb
%_kf5_libdir/libKDb3.so.%{kdb_major}{,.*}

#--------------------------------------------------------------------

%define kdb3_devel %mklibname kdb3 -d

%package -n %kdb3_devel
Summary:        Development files for %{oname}
Group:          Development/KDE and Qt
Requires:       %libkdb = %version-%release
Requires:       %name = %version-%release
Provides:       %name-devel = %version-%release
Provides:       kdb3-devel = %version-%release

%description -n %kdb3_devel
The %{kdb3_devel} package contains libraries and header files for
developing applications that use %{oname}.

%files -n %kdb3_devel
%_kf5_libdir/*.so
%_kf5_mkspecsdir/qt_KDb3.pri
%_includedir/KDb3/
%_kf5_libdir/cmake/KDb3/
%_kf5_libdir/pkgconfig/KDb3.pc

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        KDb3 APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  doxygen
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in KDb3 package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/KDb3.qch
%{_qt5_docdir}/KDb3.tags
%endif

#--------------------------------------------------------------------

%prep
%autosetup -p1 -n %{oname}-%{commit}

%build
%cmake_kf5 -Wno-dev \
           %if %{build_docs}
           -DBUILD_QCH=ON \
           %endif
           -DBUILD_TESTING=ON
%cmake_build

%install
%cmake_install

%find_lang_kf5 kdb_qt
%find_lang_kf5 kdb_mysqldriver_qt
%find_lang_kf5 kdb_postgresqldriver_qt
%find_lang_kf5 kdb_sqlitedriver_qt

cat kdb_mysqldriver_qt.lang kdb_postgresqldriver_qt.lang kdb_sqlitedriver_qt.lang >> kdb_qt.lang


%changelog
* Sat Jan 07 2023 squidf <squidf> 3.2.90-10.git20220620.mga9
+ Revision: 1931128
- Mass rebuild for icu 72.1

* Tue Oct 04 2022 papoteur <papoteur> 3.2.90-9.git20220620.mga9
+ Revision: 1894857
- Fix release number to 3.2.90

* Wed Sep 28 2022 papoteur <papoteur> 3.2.0-9.git20220620.mga9
+ Revision: 1893095
- new to snapshot from 20220620
+ squidf <squidf>
- rebuild for icu 71.1
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Aug 03 2021 luigiwalser <luigiwalser> 3.2.0-8.mga9
+ Revision: 1738935
- rebuild for icu

* Thu Dec 17 2020 umeabot <umeabot> 3.2.0-7.mga8
+ Revision: 1658654
- Rebuild for new Qt5

* Mon Nov 30 2020 luigiwalser <luigiwalser> 3.2.0-6.mga8
+ Revision: 1650892
- rebuild for icu

* Wed Jul 01 2020 wally <wally> 3.2.0-5.mga8
+ Revision: 1601031
- rebuild for icu 67.1

* Sat Apr 04 2020 wally <wally> 3.2.0-4.mga8
+ Revision: 1564467
- rebuild for new icu 66.1

* Sun Feb 16 2020 daviddavid <daviddavid> 3.2.0-3.mga8
+ Revision: 1535249
- add upstream patch to fix build with PostgreSQL 12+
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- build with new cmake macros

* Sat Oct 05 2019 daviddavid <daviddavid> 3.2.0-2.mga8
+ Revision: 1449458
- rebuild for new icu 65.1

* Sat Apr 13 2019 daviddavid <daviddavid> 3.2.0-1.mga7
+ Revision: 1389567
- new version: 3.2.0
- enable API documentation in QCH format

* Sat Mar 30 2019 umeabot <umeabot> 3.1.0-5.mga7
+ Revision: 1382166
- Qt5 Rebuild

* Fri Jan 11 2019 daviddavid <daviddavid> 3.1.0-4.mga7
+ Revision: 1354720
- rebuild for new icu

* Mon Aug 27 2018 daviddavid <daviddavid> 3.1.0-3.mga7
+ Revision: 1255077
- add patch to fix pkgconfig deps

* Mon Aug 27 2018 daviddavid <daviddavid> 3.1.0-2.mga7
+ Revision: 1254942
- rebuild for new icu

* Wed Mar 14 2018 daviddavid <daviddavid> 3.1.0-1.mga7
+ Revision: 1209197
- new version: 3.1.0
- now libmajor is 4

* Fri Dec 29 2017 wally <wally> 3.0.2-3.mga7
+ Revision: 1186981
- rebuild for new icu

* Tue Dec 26 2017 wally <wally> 3.0.2-2.mga7
+ Revision: 1185438
- rebuild for new mariadb

* Sat Aug 12 2017 daviddavid <daviddavid> 3.0.2-1.mga7
+ Revision: 1139853
- New version 3.0.2

* Tue Aug 01 2017 pterjan <pterjan> 3.0.0-5.mga7
+ Revision: 1133496
- Fix for new find_lang
- Fix for new find_lang

* Wed Mar 15 2017 mrambo3501 <mrambo3501> 3.0.0-3.mga6
+ Revision: 1092703
- Rebuild for icu-58.2

* Thu Dec 22 2016 daviddavid <daviddavid> 3.0.0-2.mga6
+ Revision: 1076479
- enable MySQL and PostgreSQL support

* Thu Dec 22 2016 neoclust <neoclust> 3.0.0-1.mga6
+ Revision: 1076363
- imported package kdb

